@@ -1,8 +1,11 @@
 from explainaboard.loaders import (
     aspect_based_sentiment_classification,
+    cloze_generative,
+    cloze_multiple_choice,
     conditional_generation,
     extractive_qa,
     file_loader,
+    grammatical_error_correction,
     kg_link_tail_prediction,
     language_modeling,
     loader,
@@ -19,6 +22,7 @@ DatalabLoaderOption = file_loader.DatalabLoaderOption
 
 __all__ = [
     'aspect_based_sentiment_classification',
+    'cloze_multiple_choice',
     'conditional_generation',
     'extractive_qa',
     'kg_link_tail_prediction',
@@ -28,4 +32,6 @@ __all__ = [
     'qa_multiple_choice',
     'text_classification',
     'text_pair_classification',
+    'cloze_generative',
+    'grammatical_error_correction',
 ]
